@@ -1,9 +1,9 @@
+from __future__ import annotations
+
 from typing import Sequence
-from typing import Tuple
 
 from pre_commit.hook import Hook
 from pre_commit.languages import helpers
-from pre_commit.languages.docker import assert_docker_available
 from pre_commit.languages.docker import docker_cmd
 
 ENVIRONMENT_DIR = None
@@ -16,7 +16,6 @@ def run_hook(
         hook: Hook,
         file_args: Sequence[str],
         color: bool,
-) -> Tuple[int, bytes]:  # pragma: win32 no cover
-    assert_docker_available()
+) -> tuple[int, bytes]:  # pragma: win32 no cover
     cmd = docker_cmd() + hook.cmd
     return helpers.run_xargs(hook, cmd, file_args, color=color)
