@@ -1,8 +1,9 @@
+from __future__ import annotations
+
 import contextlib
 import os.path
 from typing import Generator
 from typing import Sequence
-from typing import Tuple
 
 import pre_commit.constants as C
 from pre_commit.envcontext import envcontext
@@ -84,6 +85,6 @@ def run_hook(
         hook: Hook,
         file_args: Sequence[str],
         color: bool,
-) -> Tuple[int, bytes]:
+) -> tuple[int, bytes]:
     with in_env(hook.prefix):
         return helpers.run_xargs(hook, hook.cmd, file_args, color=color)
