@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from typing import Sequence
-from typing import Tuple
 
 from pre_commit.hook import Hook
 from pre_commit.languages import helpers
@@ -14,7 +15,7 @@ def run_hook(
         hook: Hook,
         file_args: Sequence[str],
         color: bool,
-) -> Tuple[int, bytes]:
+) -> tuple[int, bytes]:
     out = f'{hook.entry}\n\n'.encode()
     out += b'\n'.join(f.encode() for f in file_args) + b'\n'
     return 1, out
